@@ -354,14 +354,14 @@ static int set_kqueue_fds(struct re *re, int fd, int flags)
 
 	memset(kev, 0, sizeof(kev));
 
-	if (flags & FD_READ) {
-		EV_SET(&kev[n], fd, EVFILT_READ, EV_ADD, 0, 0, 0);
-		++n;
-	}
 	if (flags & FD_WRITE) {
 		EV_SET(&kev[n], fd, EVFILT_WRITE, EV_ADD, 0, 0, 0);
 		++n;
 	}
+	if (flags & FD_READ) {
+		EV_SET(&kev[n], fd, EVFILT_READ, EV_ADD, 0, 0, 0);
+		++n;
+	}
 
 	if (n) {
 		r = kevent(re->kqfd, kev, n, NULL, 0, NULL);
@@ -725,7 +725,7 @@ static int fd_poll(struct re *re)
 	case METHOD_KQUEUE: {
 		struct timespec timeout;
 
-		timeout.tv_sec = to / 1000;
+		timeout.tv_sec = (time_t) (to / 1000);
 		timeout.tv_nsec = (to % 1000) * 1000000;
 
 		re_unlock(re);
@@ -1081,7 +1081,7 @@ int poll_method_set(enum poll_method method)
 #endif
 #ifdef HAVE_SELECT
 	case METHOD_SELECT:
-		if (re->maxfds > FD_SETSIZE) {
+		if (re->maxfds > (int)FD_SETSIZE) {
 			DEBUG_WARNING("SELECT: maxfds > FD_SETSIZE\n");
 			return EMFILE;
 		}
