@@ -7,6 +7,8 @@
 #define OPENSSL_NO_KRB5 1
 #include <openssl/ssl.h>
 #include <openssl/err.h>
+#include <openssl/rsa.h>
+#include <openssl/bn.h>
 #include <re_types.h>
 #include <re_fmt.h>
 #include <re_mem.h>
@@ -207,16 +209,25 @@ int tls_set_selfsigned(struct tls *tls, const char *cn)
 	X509_NAME *subj = NULL;
 	EVP_PKEY *key = NULL;
 	X509 *cert = NULL;
+	BIGNUM *bn = NULL;
 	RSA *rsa = NULL;
 	int r, err = ENOMEM;
 
 	if (!tls || !cn)
 		return EINVAL;
 
-	rsa = RSA_generate_key(1024, RSA_F4, NULL, NULL);
+	rsa = RSA_new();
 	if (!rsa)
 		goto out;
 
+	bn = BN_new();
+	if (!bn)
+		goto out;
+
+	BN_set_word(bn, RSA_F4);
+	if (!RSA_generate_key_ex(rsa, 1024, bn, NULL))
+		goto out;
+
 	key = EVP_PKEY_new();
 	if (!key)
 		goto out;
@@ -286,6 +297,9 @@ int tls_set_selfsigned(struct tls *tls, const char *cn)
 	if (rsa)
 		RSA_free(rsa);
 
+	if (bn)
+		BN_free(bn);
+
 	if (err)
 		ERR_clear_error();
 
@@ -630,3 +644,19 @@ int tls_srtp_keyinfo(const struct tls_conn *tc, enum srtp_suite *suite,
 	return ENOSYS;
 #endif
 }
+
+
+/**
+ * Get cipher name of a TLS connection
+ *
+ * @param tc TLS Connection
+ *
+ * @return name of cipher actually used.
+ */
+const char *tls_cipher_name(const struct tls_conn *tc)
+{
+	if (!tc)
+		return NULL;
+
+	return SSL_get_cipher_name(tc->ssl);
+}
